@@ -5,6 +5,7 @@ import typing
 from abc import ABC
 from dataclasses import dataclass, is_dataclass
 import dataclasses
+import docstring_parser
 
 import pyron
 
@@ -113,7 +114,7 @@ class Struct:
     def find_field(self, path: Sequence[str]) -> typing.Optional[Field]:
         schema = self
         for segment in path[:-1]:
-            if segment not in self.fields:
+            if segment not in schema.fields:
                 return None
             _schema = schema.fields[segment].type
             while isinstance(_schema, Option):
@@ -169,17 +170,7 @@ def materialize_type(clz: typing.Type[Any]) -> Type:
         return List(materialize_type(clz.__args__[0]))
     elif is_dataclass(clz):
         fields = {}
-        docstrings = {}
-        if clz.__doc__ is not None:
-            for line in clz.__doc__.splitlines():
-                line = line.strip()
-                if line.startswith(":param"):
-                    line = line[len(":param ") :].strip()
-                    if ":" in line:
-                        name, docs = line.split(":", 1)
-                        name = name.strip()
-                        docs = docs.strip()
-                        docstrings[name] = docs
+        field_docs = _find_all_field_docs(clz)
         for name, field in clz.__dataclass_fields__.items():
             if field.default is not dataclasses.MISSING:
                 has_default = True
@@ -197,7 +188,7 @@ def materialize_type(clz: typing.Type[Any]) -> Type:
                 materialize_type(field.type),
                 default,
                 has_default,
-                docstrings.get(name),
+                field_docs.get(name),
             )
         from hyperstate.schema.versioned import Versioned
 
@@ -269,3 +260,14 @@ def _unwrap_container_type(type: Type) -> Type:
     if isinstance(type, Option):
         return _unwrap_container_type(type.type)
     return type
+
+
+def _find_all_field_docs(clz: typing.Type[Any]) -> typing.Dict[str, str]:
+    docs = docstring_parser.parse(clz.__doc__ or "")
+    field_docs = {
+        f.arg_name: f.description for f in docs.params if f.description is not None
+    }
+    if hasattr(clz, "__bases__"):
+        for base in clz.__bases__:
+            field_docs.update(_find_all_field_docs(base))
+    return field_docs
